@@ -34,14 +34,14 @@
 
 #include <QDebug>
 
-MainWindow::MainWindow(const QStringList& args)  :
+MainWindow::MainWindow()  :
     ui(new Ui::MainWindow)
 {
     qDebug().noquote() << QCoreApplication::applicationName() << "version:" << VERSION;
     ui->setupUi(this);
     setWindowFlags(Qt::Window); // for the close, min and max buttons
     setup();
-    ui->combo_Usb->addItems(buildUsbList());
+    ui->comboBoxUsbList->addItems(buildUsbList());
     this->adjustSize();
 }
 
@@ -55,23 +55,16 @@ void MainWindow::makeUsb(const QString &options)
 {
     //get a device value if action is on a partition
     QString device_to_check = device;
-    if (device.contains("nvme")){
+    if (device.contains("nvme")) {
         device_to_check = device.section("p",0,0);
     }
-    if (device.contains("mmc")){
+    if (device.contains("mmc")) {
         device_to_check = device.section("p",0,0);
     }
 
-    if (device.contains("sd")){
+    if (device.contains("sd")) {
         device_to_check = device.left(3);
     }
-
-    // check amount of io on device before copy, this is in sectors
-    start_io = cmd->getCmdOut("cat /sys/block/" + device_to_check + "/stat |awk '{print $7}'").toInt();
-    ui->progressBar->setMinimum(start_io);
-    qDebug() << "start io is " << start_io;
-    ui->progressBar->setMaximum(iso_sectors+start_io);
-    qDebug() << "max progress bar is " << ui->progressBar->maximum();
     //clear partitions
     //qDebug() << cmd->getCmdOut("live-usb-maker gui partition-clear --color=off -t " + device);
     QString cmdstr = options;
@@ -89,7 +82,6 @@ void MainWindow::setup()
     cmdprog = new Cmd(this);
     connect(qApp, &QApplication::aboutToQuit, this, &MainWindow::cleanup);
     this->setWindowTitle("Format USB");
-    advancedOptions = false;
     ui->buttonBack->setHidden(true);;
     ui->stackedWidget->setCurrentIndex(0);
     ui->buttonCancel->setEnabled(true);
@@ -103,21 +95,27 @@ void MainWindow::setup()
 // Build the option list to be passed to live-usb-maker
 QString MainWindow::buildOptionList()
 {
-    device = ui->combo_Usb->currentText().split(" ").at(0);
+    device = ui->comboBoxUsbList->currentText().split(" ").at(0);
     label = ui->lineEditFSlabel->text();
-    QString format = ui->comboBoxDataFormat->currentText();
-    if (format.contains("fat32")){
-        format = "vfat";
-    }
+    QString partoption;
     QString options;
-    if (ui->checkBoxshowpartitions->isChecked()) {
-        qDebug() << "partition is" << device << "label " << label;
-        options = QString("su-to-root -X -c '/usr/lib/formatusb/formatusb_lib \"" + device + "\" " + format + " \"" + label + "\" part'");
 
-    } else {
-        qDebug() << "usb device" << device << "label " << label;
-        options = QString("su-to-root -X -c '/usr/lib/formatusb/formatusb_lib \"" + device + "\" " + format + " \"" + label + "\"'");
-    }
+    QString format = ui->comboBoxDataFormat->currentText();
+    if (format.contains("fat32"))
+        format = "vfat";
+
+    if (ui->comboBoxPartitionTableType->isEnabled())
+        partoption = ui->comboBoxPartitionTableType->currentText().toLower();
+    else
+        partoption = "part";
+
+    QString authentication = "pkexec";
+    if ( !QFile::exists("/usr/bin/pkexec")){
+            authentication = "su-to-root -X -c";
+	}
+
+    qDebug() << "partition is" << device << "label " << label;
+    options = QString(authentication + " /usr/lib/formatusb/formatusb_lib \"" + device + "\" " + format + " \"" + label + "\" " + partoption + "");
     qDebug() << "Options: " << options;
     return options;
 }
@@ -132,7 +130,7 @@ void MainWindow::cleanup()
 // build the USB list
 QStringList MainWindow::buildUsbList()
 {   QString drives;
-    if (ui->checkBoxshowpartitions->isChecked()){
+    if (ui->checkBoxshowpartitions->isChecked()) {
         drives = cmd->getCmdOut("lsblk -nlo NAME,SIZE,LABEL,TYPE -I 3,8,22,179,259 |grep -v disk");
     } else {
         drives = cmd->getCmdOut("lsblk --nodeps -nlo NAME,SIZE,MODEL,VENDOR -I 3,8,22,179,259 ");
@@ -174,7 +172,6 @@ void MainWindow::cmdStart()
 
 void MainWindow::cmdDone()
 {
-    ui->progressBar->setValue(ui->progressBar->maximum());
     setCursor(QCursor(Qt::ArrowCursor));
     ui->buttonBack->setEnabled(true);
     if (cmd->exitCode() == 0 && cmd->exitStatus() == QProcess::NormalExit) {
@@ -183,26 +180,13 @@ void MainWindow::cmdDone()
         QMessageBox::critical(this, tr("Failure"), tr("Error encountered in the Format process"));
     }
     cmd->disconnect();
-    timer.stop();
 }
 
-// set proc and timer connections
 void MainWindow::setConnections()
 {
-    timer.start(1000);
     connect(cmd, &QProcess::readyRead, this, &MainWindow::updateOutput);
     connect(cmd, &QProcess::started, this, &MainWindow::cmdStart);
-    connect(&timer, &QTimer::timeout, this, &MainWindow::updateBar);
-    connect(cmd, static_cast<void (QProcess::*)(int)>(&QProcess::finished), this, &MainWindow::cmdDone);
-
-}
-
-void MainWindow::updateBar()
-{
-    if (!ui->checkBoxshowpartitions->isChecked()){
-        int current_io = cmdprog->getCmdOut("cat /sys/block/" + device + "/stat | awk '{print $7}'").toInt();
-        ui->progressBar->setValue(current_io);
-    }
+    connect(cmd, QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished), this, &MainWindow::cmdDone);
 }
 
 void MainWindow::updateOutput()
@@ -210,17 +194,8 @@ void MainWindow::updateOutput()
     // remove escape sequences that are not handled by code
     QString out = cmd->readAll();
     out.remove("[0m").remove("]0;").remove("").remove("").remove("[1000D").remove("[74C|").remove("[?25l").remove("[?25h").remove("[0;36m").remove("[1;37m");
-//    if (out.contains("[10D[K")) { // escape sequence used to display the progress percentage
-//        out.remove("[10D[K");
-//        ui->outputBox->moveCursor(QTextCursor::StartOfLine);
-//        QKeyEvent *event = new QKeyEvent(QEvent::KeyPress, Qt::Key_K, Qt::ControlModifier);
-//        QCoreApplication::postEvent(ui->outputBox, event);
-//        QString out_prog = out;
-//        ui->progressBar->setValue(out_prog.remove(" ").remove("%").toInt());
-//    }
-
+    ui->outputBox->moveCursor(QTextCursor::End);
     ui->outputBox->insertPlainText(out);
-
     QScrollBar *sb = ui->outputBox->verticalScrollBar();
     sb->setValue(sb->maximum());
     qApp->processEvents();
@@ -232,19 +207,15 @@ void MainWindow::on_buttonNext_clicked()
 
     // on first page
     if (ui->stackedWidget->currentIndex() == 0) {
-        if (ui->combo_Usb->currentText() == "") {
+        if (ui->comboBoxUsbList->currentText() == "") {
             QMessageBox::critical(this, tr("Error"), tr("Please select a USB device to write to"));
             return;
         }
 
         //confirm action
-        int ans;
-        QString msg = tr("These actions will destroy all data on \n\n") + ui->combo_Usb->currentText().simplified() + "\n\n " + tr("Do you wish to continue?");
-        ans = QMessageBox::warning(this, windowTitle(), msg,
-                                   QMessageBox::Yes, QMessageBox::No);
-        if (ans != QMessageBox::Yes) {
+        QString msg = tr("These actions will destroy all data on \n\n") + ui->comboBoxUsbList->currentText().simplified() + "\n\n " + tr("Do you wish to continue?");
+        if (QMessageBox::Yes != QMessageBox::warning(this, windowTitle(), msg, QMessageBox::Yes, QMessageBox::No))
             return;
-        }
         if (cmd->state() != QProcess::NotRunning) {
             ui->stackedWidget->setCurrentWidget(ui->outputPage);
             return;
@@ -271,7 +242,6 @@ void MainWindow::on_buttonBack_clicked()
     ui->buttonNext->setEnabled(true);
     ui->buttonBack->setDisabled(true);
     ui->outputBox->clear();
-    ui->progressBar->setValue(0);
 }
 
 
@@ -297,8 +267,8 @@ void MainWindow::on_buttonHelp_clicked()
 
 void MainWindow::on_buttonRefresh_clicked()
 {
-    ui->combo_Usb->clear();
-    ui->combo_Usb->addItems(buildUsbList());
+    ui->comboBoxUsbList->clear();
+    ui->comboBoxUsbList->addItems(buildUsbList());
 }
 
 
@@ -310,4 +280,10 @@ void MainWindow::on_checkBoxShowAll_clicked()
 void MainWindow::on_checkBoxshowpartitions_clicked()
 {
      on_buttonRefresh_clicked();
+     if ( ui->checkBoxshowpartitions->isChecked()) {
+         ui->comboBoxPartitionTableType->setEnabled(false);
+     }
+     if ( ! ui->checkBoxshowpartitions->isChecked()) {
+         ui->comboBoxPartitionTableType->setEnabled(true);
+     }
 }
